CalendarBinding class
引入provider的状态管理,保存一些临时信息
目前的情况:只需要获取状态,不需要监听rebuild
- Inheritance
-
- Object
- Bindings
- CalendarBinding
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dependencies(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited